@@ -21,11 +21,13 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA.
 from __future__ import print_function
+# pylint: disable=pointless-string-statement
 """
 usage:
        mock [options] {--init|--clean|--scrub=[all,chroot,cache,root-cache,c-cache,yum-cache,dnf-cache,lvm]}
        mock [options] [--rebuild] /path/to/srpm(s)
-       mock [options] --buildsrpm {--spec /path/to/spec --sources /path/to/src|--scm-enable [--scm-option key=value]}
+       mock [options] --buildsrpm {--spec /path/to/spec --sources /path/to/src|
+       --scm-enable [--scm-option key=value]}
        mock [options] {--shell|--chroot} <cmd>
        mock [options] --installdeps {SRPM|RPM}
        mock [options] --install PACKAGE
@@ -37,24 +39,22 @@ usage:
 """
 
 # library imports
-import grp
 import glob
+import grp
 import logging
 import logging.config
+# pylint: disable=deprecated-module
+from optparse import OptionParser
 import os
 import os.path
 import pwd
-import sys
-import time
 import shlex
 import shutil
+import sys
+import time
 
-from optparse import OptionParser
+from six.moves import configparser
 
-try:
-    import configparser
-except ImportError:
-    import ConfigParser as configparser
 
 # all of the variables below are substituted by the build system
 __VERSION__ = "unreleased_version"
@@ -73,24 +73,26 @@ logging.basicConfig(format=FORMAT, level=logging.WARNING)
 log = logging.getLogger()
 
 # our imports
-import mockbuild.exception
-from mockbuild.trace_decorator import traceLog
+# pylint: disable=wrong-import-position
+from mockbuild import util
 import mockbuild.backend
+from mockbuild.backend import Commands
+from mockbuild.buildroot import Buildroot
+import mockbuild.exception
+from mockbuild.exception import BadCmdline
+from mockbuild.plugin import Plugins
+from mockbuild.state import State
+from mockbuild.trace_decorator import traceLog
 import mockbuild.uid
 
-from mockbuild import util
-from mockbuild.backend import Commands
-from mockbuild.state import State
-from mockbuild.plugin import Plugins
-from mockbuild.buildroot import Buildroot
-from mockbuild.exception import BadCmdline
-
 
+# pylint: disable=unused-argument
 def scrub_callback(option, opt, value, parser):
     parser.values.scrub.append(value)
     parser.values.mode = "clean"
 
 
+# pylint: disable=unused-argument
 def repo_callback(optobj, opt, value, parser):
     '''Callback for the enablerepo and disablerepo option.
 
@@ -112,7 +114,8 @@ def command_parse():
                       help="rebuild the specified SRPM(s)")
     parser.add_option("--buildsrpm", action="store_const", const="buildsrpm",
                       dest="mode",
-                      help="Build a SRPM from spec (--spec ...) and sources (--sources ...) or from SCM")
+                      help="Build a SRPM from spec (--spec ...) and sources"
+                           "(--sources ...) or from SCM")
     parser.add_option("--shell", action="store_const",
                       const="shell", dest="mode",
                       help="run the specified command interactively within the chroot."
@@ -123,12 +126,14 @@ def command_parse():
     parser.add_option("--clean", action="store_const", const="clean",
                       dest="mode",
                       help="completely remove the specified chroot")
-    scrub_choices = ('chroot', 'cache', 'root-cache', 'c-cache', 'yum-cache', 'dnf-cache', 'lvm', 'all')
+    scrub_choices = ('chroot', 'cache', 'root-cache', 'c-cache', 'yum-cache',
+                     'dnf-cache', 'lvm', 'all')
     scrub_metavar = "[all|chroot|cache|root-cache|c-cache|yum-cache|dnf-cache]"
     parser.add_option("--scrub", action="callback", type="choice", default=[],
                       choices=scrub_choices, metavar=scrub_metavar,
                       callback=scrub_callback,
-                      help="completely remove the specified chroot or cache dir or all of the chroot and cache")
+                      help="completely remove the specified chroot "
+                           "or cache dir or all of the chroot and cache")
     parser.add_option("--init", action="store_const", const="init", dest="mode",
                       help="initialize the chroot, do not build anything")
     parser.add_option("--installdeps", action="store_const", const="installdeps",
@@ -205,7 +210,7 @@ def command_parse():
                            " Only active for 'rebuild'.")
     parser.add_option("--no-cleanup-after", action="store_false",
                       dest="cleanup_after", default=None,
-                      help="Dont clean chroot after building. If automatic"
+                      help="Don't clean chroot after building. If automatic"
                            " cleanup is enabled, use this to disable.", )
     parser.add_option("--cache-alterations", action="store_true",
                       dest="cache_alterations", default=False,
@@ -251,7 +256,8 @@ def command_parse():
                            " before running command when using --chroot")
 
     parser.add_option("--spec", action="store",
-                      help="Specifies spec file to use to build an SRPM (used only with --buildsrpm)")
+                      help="Specifies spec file to use to build an SRPM"
+                           "(used only with --buildsrpm)")
     parser.add_option("--sources", action="store",
                       help="Specifies sources (either a single file or a directory of files)"
                       "to use to build an SRPM (used only with --buildsrpm)")
@@ -264,10 +270,12 @@ def command_parse():
                       "Implies --no-clean. Valid options: build, install, binary")
     parser.add_option("--rpmbuild-opts", action="store",
                       help="Pass additional options to rpmbuild")
-    parser.add_option("--enablerepo", action="callback", type="string", dest="enable_disable_repos", default=[],
+    parser.add_option("--enablerepo", action="callback", type="string",
+                      dest="enable_disable_repos", default=[],
                       help="Pass enablerepo option to yum/dnf", metavar='[repo]',
                       callback=repo_callback)
-    parser.add_option("--disablerepo", action="callback", type="string", dest="enable_disable_repos", default=[],
+    parser.add_option("--disablerepo", action="callback", type="string",
+                      dest="enable_disable_repos", default=[],
                       help="Pass disablerepo option to yum/dnf", metavar='[repo]',
                       callback=repo_callback)
     parser.add_option("--old-chroot", action="store_true", dest="old_chroot",
@@ -277,7 +285,8 @@ def command_parse():
                       default=False,
                       help="use new chroot (systemd-nspawn).")
     parser.add_option("--postinstall", action="store_true", dest="post_install",
-                      default=False, help="Try to install built packages in the same buildroot right after build")
+                      default=False, help="Try to install built packages in "
+                                          "the same buildroot right after build")
 
     # verbosity
     parser.add_option("-v", "--verbose", action="store_const", const=2,
@@ -338,11 +347,13 @@ def command_parse():
     # explicitly disallow multiple targets in --target argument
     if options.rpmbuild_arch:
         if options.rpmbuild_arch.find(',') != -1:
-            raise mockbuild.exception.BadCmdline("--target option accepts only one arch. Invalid: %s" % options.rpmbuild_arch)
+            raise mockbuild.exception.BadCmdline("--target option accepts only "
+                                                 "one arch. Invalid: %s" % options.rpmbuild_arch)
 
     if options.mode == 'buildsrpm' and not (options.spec and options.sources):
         if not options.scm:
-            raise mockbuild.exception.BadCmdline("Must specify both --spec and --sources with --buildsrpm")
+            raise mockbuild.exception.BadCmdline("Must specify both --spec and "
+                                                 "--sources with --buildsrpm")
     if options.spec:
         options.spec = os.path.expanduser(options.spec)
     if options.sources:
@@ -358,7 +369,8 @@ def setup_logging(config_path, config_opts, options):
     try:
         if not os.path.exists(log_ini):
             if os.path.normpath('/etc/mock') != os.path.normpath(config_path):
-                log.warning("Could not find required logging config file: %s. Using default...", log_ini)
+                log.warning("Could not find required logging config file: %s. Using default...",
+                            log_ini)
                 log_ini = os.path.join("/etc/mock", config_opts["log_config_file"])
                 if not os.path.exists(log_ini):
                     raise IOError("Could not find log config file %s" % log_ini)
@@ -378,9 +390,12 @@ def setup_logging(config_path, config_opts, options):
 
     try:
         # set up logging format strings
-        config_opts['build_log_fmt_str'] = log_cfg.get("formatter_%s" % config_opts['build_log_fmt_name'], "format", raw=1)
-        config_opts['root_log_fmt_str'] = log_cfg.get("formatter_%s" % config_opts['root_log_fmt_name'], "format", raw=1)
-        config_opts['state_log_fmt_str'] = log_cfg.get("formatter_%s" % config_opts['state_log_fmt_name'], "format", raw=1)
+        config_opts['build_log_fmt_str'] = log_cfg.get("formatter_%s" % config_opts['build_log_fmt_name'],
+                                                       "format", raw=1)
+        config_opts['root_log_fmt_str'] = log_cfg.get("formatter_%s" % config_opts['root_log_fmt_name'],
+                                                      "format", raw=1)
+        config_opts['state_log_fmt_str'] = log_cfg.get("formatter_%s" % config_opts['state_log_fmt_name'],
+                                                       "format", raw=1)
     except configparser.NoSectionError as exc:
         log.error("Log config file (%s) missing required section: %s", log_ini, exc)
         sys.exit(50)
@@ -434,7 +449,8 @@ def check_arch_combination(target_arch, config_opts):
     host_arch = os.uname()[-1]
     if host_arch not in legal:
         raise mockbuild.exception.InvalidArchitecture(
-            "Cannot build target {0} on arch {1}, because it is not listed in legal_host_arches {2}".format(target_arch, host_arch, legal))
+            "Cannot build target {0} on arch {1}, because it is not listed in legal_host_arches {2}"
+            .format(target_arch, host_arch, legal))
 
 
 @traceLog()
@@ -495,16 +511,16 @@ def do_rebuild(config_opts, commands, buildroot, srpms):
 
         if config_opts["createrepo_on_rpms"]:
             log.info("Running createrepo on binary rpms in resultdir")
-            buildroot.uid_manager.dropPrivsTemp()
-            cmd = shlex.split(config_opts["createrepo_command"])
-            cmd.append(buildroot.resultdir)
-            util.do(cmd)
-            buildroot.uid_manager.restorePrivs()
+            with buildroot.uid_manager:
+                cmd = shlex.split(config_opts["createrepo_command"])
+                cmd.append(buildroot.resultdir)
+                util.do(cmd)
 
     rebuild_generic(srpms, commands, buildroot, config_opts, cmd=build,
                     post=post_build, clean=clean)
 
 
+# pylint: disable=unused-argument
 @traceLog()
 def do_buildsrpm(config_opts, commands, buildroot, options, args):
     # verify the input command line arguments actually exist
@@ -549,8 +565,20 @@ def groupcheck(unprivGid, tgtGid):
                            (name, ", ".join(members)))
 
 
+def running_in_docker():
+    """ Returns True if we are running inside of Docker container """
+    # Docker container has different cgroup than PID 1 of host.
+    # And have "docker" in that tree.
+    with open('/proc/self/cgroup') as f:
+        for line in f:
+            items = line.split(':')
+            if 'docker' in items[2]:
+                return True
+    return False
+
+
 @traceLog()
-def unshare_namespace():
+def unshare_namespace(config_opts):
     base_unshare_flags = util.CLONE_NEWNS
     # IPC ns is unshared later
     extended_unshare_flags = base_unshare_flags | util.CLONE_NEWUTS
@@ -563,7 +591,13 @@ def unshare_namespace():
             util.unshare(base_unshare_flags)
         except mockbuild.exception.UnshareFailed as e:
             log.error("Namespace unshare failed.")
-            sys.exit(e.resultcode)
+            if running_in_docker() and not ('docker_unshare_warning' in config_opts and
+                                            config_opts['docker_unshare_warning']):
+                log.error("It seems we are running inside of Docker. Let skip unsharing.")
+                log.error("You should *not* run anything but Mock in this container. You have been warned!")
+                time.sleep(5)
+            else:
+                sys.exit(e.resultcode)
 
 
 @traceLog()
@@ -624,7 +658,7 @@ def main():
         del os.environ['SSH_AUTH_SOCK']
 
     # elevate privs
-    uidManager._becomeUser(0, 0)
+    uidManager.become_user_without_push(0, 0)
 
     # do whatever we're here to do
     py_version = '{0}.{1}.{2}'.format(*sys.version_info[:3])
@@ -654,7 +688,7 @@ def main():
     os.environ["HOME"] = buildroot.homedir
 
     # New namespace starting from here
-    unshare_namespace()
+    unshare_namespace(config_opts)
 
     # set personality (ie. setarch)
     if config_opts['internal_setarch']:
@@ -679,10 +713,9 @@ def run_command(options, args, config_opts, commands, buildroot, state):
             raise mockbuild.exception.BadCmdline(
                 "Mock SCM module not installed: %s. You should install package mock-scm." % e)
         scmWorker = mockbuild.scm.scmWorker(log, config_opts['scm_opts'], config_opts['macros'])
-        buildroot.uid_manager.dropPrivsTemp()
-        scmWorker.get_sources()
-        buildroot.uid_manager.restorePrivs()
-        (options.sources, options.spec) = scmWorker.prepare_sources()
+        with buildroot.uid_manager:
+            scmWorker.get_sources()
+            (options.sources, options.spec) = scmWorker.prepare_sources()
 
     if options.mode == 'init':
         if config_opts['clean']:
@@ -782,8 +815,7 @@ def run_command(options, args, config_opts, commands, buildroot, state):
 
     elif options.mode == 'copyout':
         commands.init()
-        buildroot.uid_manager.dropPrivsTemp()
-        try:
+        with buildroot.uid_manager:
             if len(args) < 2:
                 log.critical("Must have source and destinations for copyout")
                 sys.exit(50)
@@ -808,8 +840,6 @@ def run_command(options, args, config_opts, commands, buildroot, state):
                         os.symlink(linkto, dest)
                     else:
                         shutil.copy(src, dest)
-        finally:
-            buildroot.uid_manager.restorePrivs()
 
     elif options.mode in ('pm-cmd', 'yum-cmd', 'dnf-cmd'):
         log.info('Running %s %s', buildroot.pkg_manager.command, ' '.join(args))
@@ -835,12 +865,15 @@ def run_command(options, args, config_opts, commands, buildroot, state):
     elif options.mode == 'mount':
         buildroot.plugins.call_hooks('mount_root')
 
-    buildroot._nuke_rpm_db()
+    buildroot.nuke_rpm_db()
     state.finish("run")
     state.alldone()
 
 if __name__ == '__main__':
-    # fix for python 2.4 logging module bug:
+    # TODO: this was documented as "fix for python 2.4 logging module bug:"
+    # TODO: ...but it is apparently still needed; without it there are various
+    # TODO:    exceptions from trace_decorator like:
+    # TODO:    TypeError: not enough arguments for format string
     logging.raiseExceptions = 0
 
     exitStatus = 0
@@ -857,7 +890,8 @@ if __name__ == '__main__':
             log.error("%s", e)
             print()
             log.error("The most common cause for this error is trying to run /usr/sbin/mock as an unprivileged user.")
-            log.error("Check your path to make sure that /usr/bin/ is listed before /usr/sbin, or manually run /usr/bin/mock to see if that fixes this problem.")
+            log.error("Check your path to make sure that /usr/bin/ is listed before /usr/sbin, "
+                      "or manually run /usr/bin/mock to see if that fixes this problem.")
             print()
         else:
             raise
@@ -878,7 +912,7 @@ if __name__ == '__main__':
         exitStatus = exc.resultcode
         log.error(str(exc))
 
-    except (Exception,) as exc:
+    except (Exception,) as exc:  # pylint: disable=broad-except
         exitStatus = 1
         log.exception(exc)
 
