@@ -106,7 +106,7 @@ class Commands(object):
                         util.rmtree(os.path.join(self.buildroot.cachedir, 'yum_cache'), selinux=self.buildroot.selinux)
                         util.rmtree(os.path.join(self.buildroot.cachedir, 'dnf_cache'), selinux=self.buildroot.selinux)
             except IOError as e:
-                getLog().warn("parts of chroot do not exist: %s", e)
+                getLog().warning("parts of chroot do not exist: %s", e)
                 raise
         finally:
             self.state.finish(statestr)
@@ -166,7 +166,7 @@ class Commands(object):
     def _show_installed_packages(self):
         '''report the installed packages in the chroot to the root log'''
         self.buildroot.root_log.info("Installed packages:")
-        self.buildroot._nuke_rpm_db()
+        self.buildroot.nuke_rpm_db()
         util.do(
             "%s --root %s -qa" % (self.config['rpm_command'],
                                   self.buildroot.make_chroot_path()),
@@ -196,7 +196,7 @@ class Commands(object):
         self.state.start(buildstate)
         # remove rpm db files to prevent version mismatch problems
         # note: moved to do this before the user change below!
-        self.buildroot._nuke_rpm_db()
+        self.buildroot.nuke_rpm_db()
         dropped_privs = False
         try:
             if not util.USE_NSPAWN:
@@ -264,7 +264,7 @@ class Commands(object):
             self.state.start("shell")
             ret = util.doshell(chrootPath=self.buildroot.make_chroot_path(),
                                environ=self.buildroot.env, uid=uid, gid=gid,
-                               user=None, cmd=cmd)
+                               cmd=cmd)
         finally:
             log.debug("shell: unmounting all filesystems")
             self.state.finish("shell")
@@ -381,23 +381,25 @@ class Commands(object):
     @traceLog()
     def rebuild_installed_srpm(self, spec_path, timeout):
         if not util.USE_NSPAWN:
-            command = ['{command} -bs --target {0} --nodeps {1}'\
-                       .format(self.rpmbuild_arch, spec_path,
-                               command=self.config['rpmbuild_command'])]
+            command = ['{command} -bs --target {0} --nodeps {1}'.format(
+                self.rpmbuild_arch, spec_path,
+                command=self.config['rpmbuild_command'])]
             command = ["bash", "--login", "-c"] + command
         else:
             command = [self.config['rpmbuild_command'], '-bs', '--target', self.rpmbuild_arch, '--nodeps', spec_path]
-        self.buildroot.doChroot(command,
-                                shell=False, logger=self.buildroot.build_log, timeout=timeout,
-                                uid=self.buildroot.chrootuid, gid=self.buildroot.chrootgid,
-                                user=self.buildroot.chrootuser,
-                                printOutput=self.config['print_main_output']
-                                )
+        self.buildroot.doChroot(
+            command,
+            shell=False, logger=self.buildroot.build_log, timeout=timeout,
+            uid=self.buildroot.chrootuid, gid=self.buildroot.chrootgid,
+            user=self.buildroot.chrootuser,
+            printOutput=self.config['print_main_output']
+        )
         results = glob.glob("%s/%s/SRPMS/*src.rpm" % (self.make_chroot_path(),
                                                       self.buildroot.builddir))
         if len(results) != 1:
             raise PkgError("Expected to find single rebuilt srpm, found %d in %s"
-                           % (len(results), "%s/%s/SRPMS/*src.rpm" % (self.make_chroot_path(), self.buildroot.builddir)))
+                           % (len(results), "%s/%s/SRPMS/*src.rpm" % (self.make_chroot_path(),
+                                                                      self.buildroot.builddir)))
         return results[0]
 
     @traceLog()
@@ -408,7 +410,10 @@ class Commands(object):
         if not check:
             # this is because EL5/6 does not know --nocheck
             # when EL5/6 targets are not supported, replace it with --nocheck
-            check_opt += ["--define",  "'__spec_check_template exit 0; '"]
+            if util.USE_NSPAWN:
+                check_opt += ["--define", "__spec_check_template exit 0; "]
+            else:
+                check_opt += ["--define", "'__spec_check_template exit 0; '"]
 
         mode = ['-bb']
         sc = self.config.get('short_circuit')
@@ -456,6 +461,6 @@ class Commands(object):
             try:
                 self.install(*pkgs)
             except:
-                self.buildroot.root_log.warn("Failed install built packages")
+                self.buildroot.root_log.warning("Failed install built packages")
         finally:
             self.uid_manager.restorePrivs()
