@@ -11,14 +11,14 @@ import shlex
 import shutil
 import stat
 import tempfile
+import uuid
 
-from . import util
 from . import mounts
-from .exception import BuildRootLocked, RootError, \
-    ResultDirNotAccessible, Error
-from .package_manager import PackageManager
-from .trace_decorator import getLog, traceLog
 from . import uid
+from . import util
+from .exception import BuildRootLocked, Error, ResultDirNotAccessible, RootError
+from .package_manager import package_manager
+from .trace_decorator import getLog, traceLog
 
 
 class Buildroot(object):
@@ -57,7 +57,7 @@ class Buildroot(object):
         self.env.update(proxy_env)
         os.environ.update(proxy_env)
 
-        self.pkg_manager = PackageManager(config, self, plugins)
+        self.pkg_manager = package_manager(config, self, plugins)
         self.mounts = mounts.Mounts(self)
 
         self.root_log = getLog("mockbuild")
@@ -101,13 +101,11 @@ class Buildroot(object):
 
     @traceLog()
     def _setup_result_dir(self):
-        self.uid_manager.dropPrivsTemp()
-        try:
-            util.mkdirIfAbsent(self.resultdir)
-        except Error:
-            raise ResultDirNotAccessible(ResultDirNotAccessible.__doc__ % self.resultdir)
-        finally:
-            self.uid_manager.restorePrivs()
+        with self.uid_manager:
+            try:
+                util.mkdirIfAbsent(self.resultdir)
+            except Error:
+                raise ResultDirNotAccessible(ResultDirNotAccessible.__doc__ % self.resultdir)
 
     @traceLog()
     def _init(self, prebuild, do_log):
@@ -173,7 +171,7 @@ class Buildroot(object):
 
     def doChroot(self, command, shell=False, nosync=False, *args, **kargs):
         """execute given command in root"""
-        self._nuke_rpm_db()
+        self.nuke_rpm_db()
         env = dict(self.env)
         if nosync and self.nosync_path:
             env['LD_PRELOAD'] = self.nosync_path
@@ -201,7 +199,7 @@ class Buildroot(object):
         if os.path.exists(orig_conf_file):
             shutil.copy2(orig_conf_file, etcdir)
         else:
-            self.root_log.warn("File %s not present. It is not copied into the chroot.", orig_conf_file)
+            self.root_log.warning("File %s not present. It is not copied into the chroot.", orig_conf_file)
 
     @traceLog()
     def _setup_resolver_config(self):
@@ -211,18 +209,14 @@ class Buildroot(object):
 
     @traceLog()
     def _setup_dbus_uuid(self):
-        try:
-            import uuid
-            machine_uuid = uuid.uuid4().hex
-            dbus_uuid_path = self.make_chroot_path('etc', 'machine-id')
-            symlink_path = self.make_chroot_path('var', 'lib', 'dbus', 'machine-id')
-            with open(dbus_uuid_path, 'w') as uuid_file:
-                uuid_file.write(machine_uuid)
-                uuid_file.write('\n')
-            if not os.path.exists(symlink_path):
-                os.symlink("../../../etc/machine-id", symlink_path)
-        except ImportError:
-            pass
+        machine_uuid = uuid.uuid4().hex
+        dbus_uuid_path = self.make_chroot_path('etc', 'machine-id')
+        symlink_path = self.make_chroot_path('var', 'lib', 'dbus', 'machine-id')
+        with open(dbus_uuid_path, 'w') as uuid_file:
+            uuid_file.write(machine_uuid)
+            uuid_file.write('\n')
+        if not os.path.exists(symlink_path):
+            os.symlink("../../../etc/machine-id", symlink_path)
 
     @traceLog()
     def _setup_timezone(self):
@@ -237,6 +231,14 @@ class Buildroot(object):
             if isinstance(cmd, util.basestring):
                 cmd = cmd.split()
             self.pkg_manager.execute(*cmd)
+
+        if 'chroot_additional_packages' in self.config and self.config['chroot_additional_packages']:
+            cmd = self.config['chroot_additional_packages']
+            if isinstance(cmd, util.basestring):
+                cmd = cmd.split()
+            cmd = ['install'] + cmd
+            self.pkg_manager.execute(*cmd)
+
         self.state.finish(update_state)
 
     @traceLog()
@@ -271,7 +273,8 @@ class Buildroot(object):
     @traceLog()
     def _enable_chrootuser_account(self):
         passwd = self.make_chroot_path('/etc/passwd')
-        lines = open(passwd).readlines()
+        with open(passwd) as f:
+            lines = f.readlines()
         disabled = False
         newlines = []
         for l in lines:
@@ -281,10 +284,9 @@ class Buildroot(object):
                 parts[1] = parts[1][2:]
             newlines.append(':'.join(parts))
         if disabled:
-            f = open(passwd, "w")
-            for l in newlines:
-                f.write(l + '\n')
-            f.close()
+            with open(passwd, "w") as f:
+                for l in newlines:
+                    f.write(l + '\n')
 
     @traceLog()
     def _resetLogging(self):
@@ -293,8 +295,7 @@ class Buildroot(object):
             return
         self.logging_initialized = True
 
-        try:
-            self.uid_manager.dropPrivsTemp()
+        with self.uid_manager:
             util.mkdirIfAbsent(self.resultdir)
 
             # attach logs to log files.
@@ -311,8 +312,6 @@ class Buildroot(object):
                 fh.setLevel(logging.NOTSET)
                 log.addHandler(fh)
                 log.info("Mock Version: %s", self.config['version'])
-        finally:
-            self.uid_manager.restorePrivs()
 
     @traceLog()
     def _init_aux_files(self):
@@ -325,7 +324,7 @@ class Buildroot(object):
                     fo.write(chroot_file_contents[key])
 
     @traceLog()
-    def _nuke_rpm_db(self):
+    def nuke_rpm_db(self):
         """remove rpm DB lock files from the chroot"""
 
         dbfiles = glob.glob(self.make_chroot_path('var/lib/rpm/__db*'))
@@ -336,7 +335,7 @@ class Buildroot(object):
         self.uid_manager.becomeUser(0, 0)
         try:
             for tmp in dbfiles:
-                self.root_log.debug("_nuke_rpm_db: removing %s", tmp)
+                self.root_log.debug("nuke_rpm_db: removing %s", tmp)
                 try:
                     os.unlink(tmp)
                 except OSError as e:
@@ -402,27 +401,22 @@ class Buildroot(object):
     def _setup_build_dirs(self):
         build_dirs = ['RPMS', 'SPECS', 'SRPMS', 'SOURCES', 'BUILD', 'BUILDROOT',
                       'originals']
-        self.uid_manager.dropPrivsTemp()
-        try:
+        with self.uid_manager:
             for item in build_dirs:
                 util.mkdirIfAbsent(self.make_chroot_path(self.builddir, item))
             if self.config['clean']:
                 self.chown_home_dir()
             # rpmmacros default
             macrofile_out = self.make_chroot_path(self.homedir, ".rpmmacros")
-            rpmmacros = open(macrofile_out, 'w+')
+            with open(macrofile_out, 'w+') as rpmmacros:
 
-            # user specific from rpm macro file defenitions first
-            if 'macrofile' in self.config:
-                macro_conf = open(self.config['macrofile'], 'r')
-                rpmmacros.write("%s\n\n" % macro_conf.read())
-                macro_conf.close()
+                # user specific from rpm macro file definitions first
+                if 'macrofile' in self.config:
+                    with open(self.config['macrofile'], 'r') as macro_conf:
+                        rpmmacros.write("%s\n\n" % macro_conf.read())
 
-            for key, value in list(self.config['macros'].items()):
-                rpmmacros.write("%s %s\n" % (key, value))
-            rpmmacros.close()
-        finally:
-            self.uid_manager.restorePrivs()
+                for key, value in list(self.config['macros'].items()):
+                    rpmmacros.write("%s %s\n" % (key, value))
 
     @traceLog()
     def _setup_devices(self):
@@ -520,13 +514,13 @@ class Buildroot(object):
             copied_lib = copy_nosync()
             copied_lib64 = copy_nosync(lib64=True)
             if not copied_lib and not copied_lib64:
-                self.root_log.warn("nosync is enabled but the library wasn't "
-                                   "found on the system")
+                self.root_log.warning("nosync is enabled but the library "
+                                      "wasn't found on the system")
                 return
             if (target_arch in multilib and not self.config['nosync_force']
                     and copied_lib != copied_lib64):
-                self.root_log.warn("For multilib systems, both architectures "
-                                   "of nosync library need to be installed")
+                self.root_log.warning("For multilib systems, both architectures"
+                                      " of nosync library need to be installed")
                 return
             self.nosync_path = os.path.join(tmp_libdir, 'nosync.so')
 
