@@ -1,12 +1,12 @@
 # -*- coding: utf-8 -*-
 # vim: noai:ts=4:sw=4:expandtab
 
+import grp
 import os
 import os.path
-import grp
 
-from . import util
 from . import exception
+from . import util
 from .trace_decorator import traceLog
 
 
@@ -19,8 +19,9 @@ class MountPoint(object):
 
     @traceLog()
     def ismounted(self):
-        if self.mountpath in [x.split()[1] for x in open('/proc/mounts')]:
-            return True
+        with open('/proc/mounts') as f:
+            if self.mountpath in [x.split()[1] for x in f]:
+                return True
         return False
 
 
@@ -58,6 +59,7 @@ class FileSystemMountPoint(MountPoint):
         return True
 
     @traceLog()
+    # pylint: disable=unused-argument
     def umount(self, force=False, nowarn=False):
         if not self.mounted:
             return
@@ -106,13 +108,14 @@ class Mounts(object):
         self.rootObj = rootObj
         self.mounts = []
         if not util.USE_NSPAWN:
-            self.mounts = [FileSystemMountPoint(filetype='proc',
-                                                device='mock_chroot_proc',
-                                                path=rootObj.make_chroot_path('/proc')),
-                           FileSystemMountPoint(filetype='sysfs',
-                                                device='mock_chroot_sys',
-                                                path=rootObj.make_chroot_path('/sys')),
-                          ]
+            self.mounts = [
+                FileSystemMountPoint(filetype='proc',
+                                     device='mock_chroot_proc',
+                                     path=rootObj.make_chroot_path('/proc')),
+                FileSystemMountPoint(filetype='sysfs',
+                                     device='mock_chroot_sys',
+                                     path=rootObj.make_chroot_path('/sys')),
+            ]
             if rootObj.config['internal_dev_setup']:
                 self.mounts.append(FileSystemMountPoint(filetype='tmpfs',
                                                         device='mock_chroot_shmfs',
@@ -134,6 +137,7 @@ class Mounts(object):
             m.mount()
 
     @traceLog()
+    # pylint: disable=unused-argument
     def umountall(self, force=False, nowarn=False):
         for m in reversed(self.mounts):
             m.umount()
