@@ -7,10 +7,9 @@
 # python library imports
 
 # our imports
-from mockbuild.trace_decorator import traceLog, getLog
-import mockbuild.util
-
 from mockbuild.mounts import BindMountPoint
+from mockbuild.trace_decorator import getLog, traceLog
+import mockbuild.util
 
 requires_api_version = "1.1"
 
@@ -35,7 +34,8 @@ class CCache(object):
         buildroot.preexisting_deps.append("ccache")
         plugins.add_hook("prebuild", self._ccacheBuildHook)
         plugins.add_hook("preinit", self._ccachePreInitHook)
-        buildroot.mounts.add(BindMountPoint(srcpath=self.ccachePath, bindpath=buildroot.make_chroot_path("/tmp/ccache")))
+        buildroot.mounts.add(
+            BindMountPoint(srcpath=self.ccachePath, bindpath=buildroot.make_chroot_path("/tmp/ccache")))
 
     # =============
     # 'Private' API
