@@ -14,11 +14,10 @@
 # our imports
 from mockbuild.trace_decorator import traceLog
 import mockbuild.util
-import tempfile
-import os
 
 # repoquery used
-repoquery_avail_opts = "--qf '%{name}-%{epoch}:%{version}-%{release}.%{arch} %{buildtime} %{size} %{pkgid} %{repoid}' '*'"
+repoquery_avail_opts = \
+    "--qf '%{name}-%{epoch}:%{version}-%{release}.%{arch} %{buildtime} %{size} %{pkgid} %{repoid}' '*'"
 
 # set up logging, module options
 requires_api_version = "1.1"
@@ -35,48 +34,41 @@ class PackageState(object):
     @traceLog()
     def __init__(self, plugins, conf, buildroot):
         self.buildroot = buildroot
-        self.config = buildroot.config
         self.state = buildroot.state
+        self.conf = conf
+        self.available_pkgs_enabled = self.conf['available_pkgs']
+        self.installed_pkgs_enabled = self.conf['installed_pkgs']
         self.avail_done = False
         self.inst_done = False
-        self.online = self.config['online']
+        self.online = self.buildroot.config['online']
         plugins.add_hook("postyum", self._availablePostYumHook)
         plugins.add_hook("prebuild", self._installedPreBuildHook)
 
     @traceLog()
     def _availablePostYumHook(self):
-        if self.online and not self.avail_done:
-            self.buildroot.uid_manager.dropPrivsTemp()
-            self.state.start("Outputting list of available packages")
-            out_file = self.buildroot.resultdir + '/available_pkgs'
-            chrootpath = self.buildroot.make_chroot_path()
-            if self.config['package_manager'] == 'dnf':
-                cmd = "/usr/bin/repoquery --installroot={0} -c {0}/etc/yum.conf {1} > {2}".format(
-                    chrootpath, repoquery_avail_opts, out_file)
-            else:
-                cmd = "/usr/bin/dnf --installroot={0} repoquery -c {0}/etc/dnf.conf {1} > {2}".format(
-                    chrootpath, repoquery_avail_opts, out_file)
-            # print(cmd)
-            mockbuild.util.do(cmd, shell=True, env=self.buildroot.env)
-            self.avail_done = True
-            self.state.finish("Outputting list of available packages")
-            self.buildroot.uid_manager.restorePrivs()
+        if self.online and not self.avail_done and self.available_pkgs_enabled:
+            with self.buildroot.uid_manager:
+                self.state.start("Outputting list of available packages")
+                out_file = self.buildroot.resultdir + '/available_pkgs'
+                chrootpath = self.buildroot.make_chroot_path()
+                if self.buildroot.config['package_manager'] == 'dnf':
+                    cmd = "/usr/bin/dnf --installroot={0} repoquery -c {0}/etc/dnf.conf {1} > {2}".format(
+                        chrootpath, repoquery_avail_opts, out_file)
+                else:
+                    cmd = "/usr/bin/repoquery --installroot={0} -c {0}/etc/yum.conf {1} > {2}".format(
+                        chrootpath, repoquery_avail_opts, out_file)
+                mockbuild.util.do(cmd, shell=True, env=self.buildroot.env)
+                self.avail_done = True
+                self.state.finish("Outputting list of available packages")
 
     @traceLog()
     def _installedPreBuildHook(self):
-        if self.online and not self.inst_done:
+        if not self.inst_done and self.installed_pkgs_enabled:
             self.state.start("Outputting list of installed packages")
-            fd, fn = tempfile.mkstemp()
-            fo = os.fdopen(fd, 'w')
-            fo.write('[main]\ninstallroot=%s' % self.buildroot.make_chroot_path())
-            fo.flush()
-            fo.close()
             out_file = self.buildroot.resultdir + '/installed_pkgs'
             cmd = "rpm -qa --root '%s' --qf '%%{nevra} %%{buildtime} %%{size} %%{pkgid} installed\\n' > %s" % (
                 self.buildroot.make_chroot_path(), out_file)
-            self.buildroot.uid_manager.restorePrivs()
-            mockbuild.util.do(cmd, shell=True, env=self.buildroot.env)
-            self.buildroot.uid_manager.dropPrivsTemp()
+            with self.buildroot.uid_manager:
+                mockbuild.util.do(cmd, shell=True, env=self.buildroot.env)
             self.inst_done = True
-            os.unlink(fn)
             self.state.finish("Outputting list of installed packages")
