@@ -10,7 +10,7 @@ import os
 import time
 
 # our imports
-from mockbuild.trace_decorator import traceLog, getLog
+from mockbuild.trace_decorator import getLog, traceLog
 import mockbuild.util
 
 requires_api_version = "1.1"
@@ -165,14 +165,13 @@ class RootCache(object):
         try:
             self._rootCacheLock(shared=0)
             # nuke any rpmdb tmp files
-            self.buildroot._nuke_rpm_db()
+            self.buildroot.nuke_rpm_db()
 
             # truncate the sparse files in /var/log
             for logfile in ('/var/log/lastlog', '/var/log/faillog'):
                 try:
-                    f = open(self.buildroot.make_chroot_path(logfile), "w")
-                    f.truncate(0)
-                    f.close()
+                    with open(self.buildroot.make_chroot_path(logfile), "w") as f:
+                        f.truncate(0)
                 except (IOError, OSError):
                     pass
 
@@ -180,7 +179,7 @@ class RootCache(object):
             if not self.buildroot.chroot_was_initialized or self.config['cache_alterations']:
                 mockbuild.util.do(["sync"], shell=False)
                 self._root_cache_handle_mounts()
-                self.state.start("creating cache")
+                self.state.start("creating root cache")
                 try:
                     mockbuild.util.do(
                         ["tar", "--one-file-system", "--exclude-caches", "--exclude-caches-under"] +
@@ -196,12 +195,11 @@ class RootCache(object):
                     raise
                 # now create the cache log file
                 try:
-                    l = open(os.path.join(self.rootSharedCachePath, "cache.log"), "w")
-                    l.write(self.buildroot.yum_init_install_output)
-                    l.close()
+                    with open(os.path.join(self.rootSharedCachePath, "cache.log"), "w") as l:
+                        l.write(self.buildroot.yum_init_install_output)
                 except:
                     pass
-                self.state.finish("creating cache")
+                self.state.finish("creating root cache")
         finally:
             self._rootCacheUnlock()
 
