@@ -5,11 +5,12 @@
 # Copyright (C) 2014 Facebook
 
 # python library imports
-from mockbuild.trace_decorator import traceLog, getLog
 import glob
 import os
 import subprocess
 
+from mockbuild.trace_decorator import getLog, traceLog
+
 requires_api_version = "1.1"
 
 
@@ -39,6 +40,5 @@ class Sign(object):
             opts = self.conf['opts'] % {'rpms': ' '.join(rpms), 'resultdir': self.buildroot.resultdir}
             cmd = "{0} {1}".format(self.conf['cmd'], opts)
             getLog().info("Executing %s", cmd)
-            self.buildroot.uid_manager.dropPrivsTemp()
-            subprocess.call(cmd, shell=True, env=os.environ)
-            self.buildroot.uid_manager.restorePrivs()
+            with self.buildroot.uid_manager:
+                subprocess.call(cmd, shell=True, env=os.environ)
