@@ -8,7 +8,7 @@
 import os
 
 # our imports
-from mockbuild.trace_decorator import traceLog, getLog
+from mockbuild.trace_decorator import getLog, traceLog
 import mockbuild.util
 
 requires_api_version = "1.1"
@@ -92,5 +92,6 @@ class Tmpfs(object):
             try:
                 mockbuild.util.do(umountCmd, shell=False)
             except:
-                getLog().warning("tmpfs-plugin: exception while force umounting tmpfs! (cwd: %s)", mockbuild.util.pretty_getcwd())
+                getLog().warning(
+                    "tmpfs-plugin: exception while force umounting tmpfs! (cwd: %s)", mockbuild.util.pretty_getcwd())
         self.mounted = False
