@@ -7,13 +7,14 @@
 import os
 import shlex
 import shutil
-import six
 import subprocess
 import sys
 import tempfile
 
-from .trace_decorator import traceLog
+import six
+
 from . import util
+from .trace_decorator import traceLog
 
 
 class scmWorker(object):
@@ -96,13 +97,13 @@ class scmWorker(object):
         os.chdir(self.src_dir)
         proc = subprocess.Popen(['git', 'ls-files', '-z'], shell=False, stdout=subprocess.PIPE)
         for f in proc.communicate()[0].split('\0')[:-1]:
-            rev = subprocess.Popen(['git', 'rev-list', 'HEAD', f], shell=False,
-                                   stdout=subprocess.PIPE
-                                  ).stdout.readlines()[0].rstrip('\n')
-            ts = subprocess.Popen(['git', 'show', '--pretty=format:%ai', '--abbrev-commit', rev, f],
-                                  shell=False,
-                                  stdout=subprocess.PIPE
-                                 ).stdout.readlines()[0].rstrip('\n')
+            rev = subprocess.Popen(
+                ['git', 'rev-list', 'HEAD', f], shell=False, stdout=subprocess.PIPE
+            ).stdout.readlines()[0].rstrip('\n')
+            ts = subprocess.Popen(
+                ['git', 'show', '--pretty=format:%ai', '--abbrev-commit', rev, f],
+                shell=False, stdout=subprocess.PIPE
+            ).stdout.readlines()[0].rstrip('\n')
             subprocess.Popen(['touch', '-d', ts, f], shell=False)
         os.chdir(cwd_dir)
 
@@ -138,11 +139,7 @@ class scmWorker(object):
         self.name = rpm.expandMacro("%{name}")
         self.version = rpm.expandMacro("%{version}")
         tarball = None
-        try:
-            sources_list = rpm_spec.sources()
-        except:
-            sources_list = rpm_spec.sources
-        for (filename, num, flags) in sources_list:
+        for (filename, num, flags) in rpm_spec.sources:
             self.sources.append(filename.split("/")[-1])
             if num == 0 and flags == 1:
                 tarball = filename.split("/")[-1]
@@ -164,6 +161,7 @@ class scmWorker(object):
                 proc = subprocess.Popen(['tar', '--help'], shell=False, stdout=subprocess.PIPE)
                 proc_result = proc.communicate()[0]
                 if six.PY3:
+                    # pylint: disable=redefined-variable-type
                     proc_result = proc_result.decode()
                 if "--exclude-vcs" in proc_result:
                     taropts = "--exclude-vcs"
