@@ -23,17 +23,26 @@ class UidManager(object):
         self.unprivEnviron = dict(os.environ)
         self.unprivEnviron['HOME'] = pwd.getpwuid(unprivUid).pw_dir
 
+    @traceLog()
+    def __enter__(self):
+        self.dropPrivsTemp()
+        return self
+
+    @traceLog()
+    def __exit__(self, exc_type, exc_val, exc_tb):
+        self.restorePrivs()
+
     @traceLog()
     def becomeUser(self, uid, gid=-1):
         # save current ruid, euid, rgid, egid
         self._push()
-        self._becomeUser(uid, gid)
+        self.become_user_without_push(uid, gid)
 
     @traceLog()
     def dropPrivsTemp(self):
         # save current ruid, euid, rgid, egid
         self._push()
-        self._becomeUser(self.unprivUid, self.unprivGid)
+        self.become_user_without_push(self.unprivUid, self.unprivGid)
         os.environ.clear()
         os.environ.update(self.unprivEnviron)
 
@@ -67,12 +76,13 @@ class UidManager(object):
         self.privEnviron.append(dict(os.environ))
 
     @traceLog()
+    # pylint: disable=no-self-use
     def _elevatePrivs(self):
         setresuid(0, 0, 0)
         os.setregid(0, 0)
 
     @traceLog()
-    def _becomeUser(self, uid, gid=None):
+    def become_user_without_push(self, uid, gid=None):
         self._elevatePrivs()
         if gid is not None:
             os.setregid(gid, gid)
