@@ -7,8 +7,14 @@
 # Copyright (C) 2007 Michael E Brown <mebrown@michaels-house.net>
 from __future__ import print_function
 
+from ast import literal_eval
 import ctypes
+import errno
 import fcntl
+from glob import glob
+import grp
+import locale
+import logging
 import os
 import os.path
 import pickle
@@ -16,28 +22,24 @@ import pwd
 import re
 import select
 import signal
+import socket
+import stat
+import struct
 import subprocess
 import sys
-import stat
-import time
-import errno
-import grp
-import locale
-import logging
-import uuid
 import termios
-import struct
-from glob import glob
-from ast import literal_eval
 from textwrap import dedent
+import time
+import uuid
 
 from . import exception
-from .trace_decorator import traceLog, getLog
-from .uid import setresuid, setresgid, getresuid, getresgid
+from .trace_decorator import getLog, traceLog
+from .uid import getresuid, setresuid
 
 encoding = locale.getpreferredencoding()
 
 try:
+    # pylint: disable=used-before-assignment
     basestring = basestring
 except NameError:
     basestring = str
@@ -197,17 +199,17 @@ def orphansKill(rootToKill, killsig=signal.SIGTERM):
         vm_list = '\n'.join(vm_list.split('\n')[1:-2])
         for name in vm_list.split("\n"):
             if len(name) > 0:
-                M_UUID = name.split()[0]
+                m_uuid = name.split()[0]
                 try:
-                    vm_root = subprocess.check_output(["/usr/bin/machinectl", "show", "-pRootDirectory", M_UUID])
+                    vm_root = subprocess.check_output(["/usr/bin/machinectl", "show", "-pRootDirectory", m_uuid])
                     if (isinstance(vm_root, bytes)):
                         vm_root = vm_root.decode("utf-8")
                 except subprocess.CalledProcessError:
                     continue
                 vm_root = '='.join(vm_root.rstrip().split('=')[1:])
                 if vm_root == rootToKill:
-                    getLog().warning("Machine %s still running. Killing...", M_UUID)
-                    os.system("/usr/bin/machinectl terminate %s" % M_UUID)
+                    getLog().warning("Machine %s still running. Killing...", m_uuid)
+                    os.system("/usr/bin/machinectl terminate %s" % m_uuid)
 
 
 @traceLog()
@@ -266,6 +268,7 @@ def cmpKernelVer(str1, str2):
 @traceLog()
 def getAddtlReqs(hdr, conf):
     # Add the 'more_buildreqs' for this SRPM (if defined in config file)
+    # pylint: disable=unused-variable
     (name, epoch, ver, rel, arch) = getNEVRA(hdr)
     reqlist = []
     for this_srpm in ['-'.join([name, ver, rel]),
@@ -355,7 +358,8 @@ def process_input(line):
     return ''.join(out)
 
 
-def logOutput(fds, logger, returnOutput=1, start=0, timeout=0, printOutput=False, child=None, chrootPath=None, pty=False):
+def logOutput(fds, logger, returnOutput=1, start=0, timeout=0, printOutput=False,
+              child=None, chrootPath=None, pty=False):
     output = ""
     done = 0
 
@@ -399,6 +403,7 @@ def logOutput(fds, logger, returnOutput=1, start=0, timeout=0, printOutput=False
                 if printOutput:
                     if hasattr(sys.stdout, 'buffer'):
                         # python3 would print binary strings ugly
+                        # pylint: disable=no-member
                         sys.stdout.buffer.write(raw)
                     else:
                         print(raw, end='')
@@ -440,18 +445,20 @@ def logOutput(fds, logger, returnOutput=1, start=0, timeout=0, printOutput=False
 @traceLog()
 def selinuxEnabled():
     """Check if SELinux is enabled (enforcing or permissive)."""
-    for mount in open("/proc/mounts").readlines():
-        (fstype, mountpoint, _) = mount.split(None, 2)
-        if fstype == "selinuxfs":
-            selinux_mountpoint = mountpoint
-            break
-    else:
-        selinux_mountpoint = "/selinux"
+    with open("/proc/mounts") as f:
+        for mount in f.readlines():
+            (fstype, mountpoint, _) = mount.split(None, 2)
+            if fstype == "selinuxfs":
+                selinux_mountpoint = mountpoint
+                break
+        else:
+            selinux_mountpoint = "/selinux"
 
     try:
         enforce_filename = os.path.join(selinux_mountpoint, "enforce")
-        if open(enforce_filename).read().strip() in ("1", "0"):
-            return True
+        with open(enforce_filename) as f:
+            if f.read().strip() in ("1", "0"):
+                return True
     except:
         pass
     return False
@@ -474,6 +481,7 @@ def resize_pty(pty):
 # The "Not-as-complicated" version
 #
 @traceLog()
+# pylint: disable=unused-argument
 def do(command, shell=False, chrootPath=None, cwd=None, timeout=0, raiseExc=True,
        returnOutput=0, uid=None, gid=None, user=None, personality=None,
        printOutput=False, env=None, pty=False, private_network=False,
@@ -489,28 +497,36 @@ def do(command, shell=False, chrootPath=None, cwd=None, timeout=0, raiseExc=True
     preexec = ChildPreExec(personality, chrootPath, cwd, uid, gid, unshare_ipc=bool(chrootPath))
     if env is None:
         env = clean_env()
+    stdout = None
     try:
         child = None
         if shell and isinstance(command, list):
             command = ['/bin/sh', '-c'] + command
             shell = False
         if chrootPath and USE_NSPAWN:
-            command = _prepare_nspawn_command(chrootPath, user, command, private_network=private_network, env=env)
+            command = _prepare_nspawn_command(chrootPath, user, command,
+                                              private_network=private_network, env=env, cwd=cwd)
         logger.debug("Executing command: %s with env %s and shell %s", command, env, shell)
-        child = subprocess.Popen(
-            command,
-            shell=shell,
-            env=env,
-            bufsize=0, close_fds=True,
-            stdin=open("/dev/null", "r"),
-            stdout=slave_pty if pty else subprocess.PIPE,
-            stderr=subprocess.PIPE,
-            preexec_fn=preexec,
-        )
-        # use select() to poll for output so we dont block
-        output = logOutput([reader if pty else child.stdout, child.stderr],
-                           logger, returnOutput, start, timeout, pty=pty,
-                           printOutput=printOutput, child=child, chrootPath=chrootPath)
+        with open(os.devnull, "r") as stdin:
+            child = subprocess.Popen(
+                command,
+                shell=shell,
+                env=env,
+                bufsize=0, close_fds=True,
+                stdin=stdin,
+                stdout=slave_pty if pty else subprocess.PIPE,
+                stderr=subprocess.PIPE,
+                preexec_fn=preexec,
+            )
+            if not pty:
+                stdout = child.stdout
+            with child.stderr:
+                # use select() to poll for output so we dont block
+                output = logOutput(
+                    [reader if pty else child.stdout, child.stderr],
+                    logger, returnOutput, start, timeout, pty=pty,
+                    printOutput=printOutput, child=child,
+                    chrootPath=chrootPath)
     except:
         # kill children if they arent done
         if child is not None and child.returncode is None:
@@ -525,6 +541,8 @@ def do(command, shell=False, chrootPath=None, cwd=None, timeout=0, raiseExc=True
         if pty:
             os.close(slave_pty)
             reader.close()
+        if stdout:
+            stdout.close()
 
     # wait until child is done, kill it if it passes timeout
     niceExit = 1
@@ -593,12 +611,12 @@ def is_in_dir(path, directory):
     return os.path.commonprefix([path, directory]) == directory
 
 
-def _prepare_nspawn_command(chrootPath, user, cmd, private_network=False, env=None):
+def _prepare_nspawn_command(chrootPath, user, cmd, private_network=False, env=None, cwd=None):
     cmd_is_list = isinstance(cmd, list)
     if user:
-        # needs to be /bin because of el5 and el6 targets
+        # user can be either id or name
         if cmd_is_list:
-            cmd = ['-u', user] + cmd
+            cmd = ['-u', str(user)] + cmd
         else:
             raise exception.Error('Internal Error: command must be list or shell=True.')
     elif not cmd_is_list:
@@ -606,6 +624,8 @@ def _prepare_nspawn_command(chrootPath, user, cmd, private_network=False, env=No
     nspawn_argv = ['/usr/bin/systemd-nspawn', '-q', '-M', uuid.uuid4().hex, '-D', chrootPath]
     if private_network:
         nspawn_argv.append('--private-network')
+    if cwd:
+        nspawn_argv.append('--chdir={0}'.format(cwd))
     if env:
         # BZ 1312384 workaround
         env['PROMPT_COMMAND'] = 'printf "\\033]0;<mock-chroot>\\007"'
@@ -619,7 +639,7 @@ def _prepare_nspawn_command(chrootPath, user, cmd, private_network=False, env=No
         return " ".join(cmd)
 
 
-def doshell(chrootPath=None, environ=None, uid=None, gid=None, user=None, cmd=None,
+def doshell(chrootPath=None, environ=None, uid=None, gid=None, cmd=None,
             unshare_ipc=True):
     log = getLog()
     log.debug("doshell: chrootPath:%s, uid:%d, gid:%d", chrootPath, uid, gid)
@@ -639,7 +659,8 @@ def doshell(chrootPath=None, environ=None, uid=None, gid=None, user=None, cmd=No
     else:
         cmd = ["/bin/sh", "-i", "-l"]
     if USE_NSPAWN:
-        cmd = _prepare_nspawn_command(chrootPath, user, cmd, env=environ)
+        # nspawn cannot set gid
+        cmd = _prepare_nspawn_command(chrootPath, uid, cmd, env=environ)
     preexec = ChildPreExec(personality=None, chrootPath=chrootPath, cwd=None,
                            uid=uid, gid=gid, env=environ, shell=True,
                            unshare_ipc=unshare_ipc)
@@ -654,12 +675,13 @@ def run(cmd, isShell=True):
 
 
 def clean_env():
-    env = {'TERM': 'vt100',
-           'SHELL': '/bin/sh',
-           'HOME': '/builddir',
-           'HOSTNAME': 'mock',
-           'PATH': '/usr/bin:/bin:/usr/sbin:/sbin',
-           }
+    env = {
+        'TERM': 'vt100',
+        'SHELL': '/bin/sh',
+        'HOME': '/builddir',
+        'HOSTNAME': 'mock',
+        'PATH': '/usr/bin:/bin:/usr/sbin:/sbin',
+    }
     env['LANG'] = os.environ.setdefault('LANG', 'en_US.UTF-8')
     return env
 
@@ -669,7 +691,8 @@ def get_fs_type(path):
     p = subprocess.Popen(cmd, shell=True, stdout=subprocess.PIPE,
                          universal_newlines=True)
     p.wait()
-    return p.stdout.readline().strip()
+    with p.stdout as f:
+        return f.readline().strip()
 
 
 def find_non_nfs_dir():
@@ -706,6 +729,7 @@ def setup_default_config_opts(unprivUid, version, pkgpythondir):
     config_opts['online'] = True
     config_opts['use_nspawn'] = False
     config_opts['rpmbuild_networking'] = False
+    config_opts['use_container_host_hostname'] = True
 
     config_opts['internal_dev_setup'] = True
     config_opts['internal_setarch'] = True
@@ -774,7 +798,10 @@ def setup_default_config_opts(unprivUid, version, pkgpythondir):
         'selinux_enable': True,
         'selinux_opts': {},
         'package_state_enable': False,
-        'package_state_opts': {},
+        'package_state_opts': {
+            'available_pkgs': False,
+            'installed_pkgs': True,
+        },
         'pm_request_enable': False,
         'pm_request_opts': {},
         'lvm_root_enable': False,
@@ -824,7 +851,7 @@ def setup_default_config_opts(unprivUid, version, pkgpythondir):
         'git_get': 'git clone SCM_BRN git://localhost/SCM_PKG.git SCM_PKG',
         'svn_get': 'svn co file:///srv/svn/SCM_PKG/SCM_BRN SCM_PKG',
         'spec': 'SCM_PKG.spec',
-        'ext_src_dir': '/dev/null',
+        'ext_src_dir': os.devnull,
         'write_tar': False,
         'git_timestamps': False,
         'exclude_vcs': True,
@@ -1027,7 +1054,26 @@ def set_config_opts_per_cmdline(config_opts, options, args):
 
 def check_config(config_opts):
     if 'root' not in config_opts:
-        raise exception.ConfigError("Error in configuration - option config_opts['root'] must be present in your config.")
+        raise exception.ConfigError("Error in configuration "
+                                    "- option config_opts['root'] must be present in your config.")
+
+
+@traceLog()
+def include(config_file, config_opts, is_statement=False):
+    if os.path.exists(config_file):
+        if is_statement and config_file in config_opts['config_paths']:
+            getLog().warning("Multiple inclusion of %s, skipping" % config_file)
+            return
+
+        config_opts['config_paths'].append(config_file)
+
+        with open(config_file) as f:
+            content = f.read()
+            content = re.sub(r'include\((.*)\)', r'include(\g<1>, config_opts, True)', content)
+            code = compile(content, config_file, 'exec')
+        exec(code)
+    else:
+        raise exception.ConfigError("Could not find included config file: %s" % config_file)
 
 
 @traceLog()
@@ -1039,9 +1085,7 @@ def update_config_from_file(config_opts, config_file, uid_manager):
             os.close(r_pipe)
             if uid_manager and not all(getresuid()):
                 uid_manager.dropPrivsForever()
-            with open(config_file) as f:
-                code = compile(f.read(), config_file, 'exec')
-            exec(code)
+            include(config_file, config_opts)
             writer = os.fdopen(w_pipe, 'wb')
             pickle.dump(config_opts, writer)
         except:
@@ -1077,26 +1121,26 @@ def update_config_from_file(config_opts, config_file, uid_manager):
 @traceLog()
 def do_update_config(log, config_opts, cfg, uidManager, name, skipError=True):
     if os.path.exists(cfg):
-            config_opts['config_paths'].append(cfg)
-            update_config_from_file(config_opts, cfg, uidManager)
-            check_macro_definition(config_opts)
+        config_opts['config_paths'].append(cfg)
+        update_config_from_file(config_opts, cfg, uidManager)
+        check_macro_definition(config_opts)
     elif not skipError:
-            log.error("Could not find required config file: %s", cfg)
-            if name == "default":
-                log.error("  Did you forget to specify the chroot to use with '-r'?")
-            if "/" in cfg:
-                log.error("  If you're trying to specify a path, include the .cfg extension, e.g. -r ./target.cfg")
-            sys.exit(1)
+        log.error("Could not find required config file: %s", cfg)
+        if name == "default":
+            log.error("  Did you forget to specify the chroot to use with '-r'?")
+        if "/" in cfg:
+            log.error("  If you're trying to specify a path, include the .cfg extension, e.g. -r ./target.cfg")
+        sys.exit(1)
 
 
 @traceLog()
-def load_config(config_path, name, uidManager, version, PKGPYTHONDIR):
+def load_config(config_path, name, uidManager, version, pkg_python_dir):
     log = logging.getLogger()
     if uidManager:
         gid = uidManager.unprivUid
     else:
         gid = os.getuid()
-    config_opts = setup_default_config_opts(gid, version, PKGPYTHONDIR)
+    config_opts = setup_default_config_opts(gid, version, pkg_python_dir)
 
     # array to save config paths
     config_opts['config_paths'] = []
@@ -1121,8 +1165,8 @@ def load_config(config_path, name, uidManager, version, PKGPYTHONDIR):
     cfg = os.path.join(os.path.expanduser(
         '~' + pwd.getpwuid(os.getuid())[0]), '.mock/user.cfg')
     do_update_config(log, config_opts, cfg, uidManager, name)
-    cfg = os.path.join(os.path.expanduser('~' + pwd.getpwuid(os.getuid())[0]),
-            '.config/mock.cfg')
+    cfg = os.path.join(os.path.expanduser(
+        '~' + pwd.getpwuid(os.getuid())[0]), '.config/mock.cfg')
     do_update_config(log, config_opts, cfg, uidManager, name)
 
     # default /etc/hosts contents
@@ -1131,6 +1175,8 @@ def load_config(config_path, name, uidManager, version, PKGPYTHONDIR):
             127.0.0.1 localhost localhost.localdomain
             ::1       localhost localhost.localdomain localhost6 localhost6.localdomain6
             ''')
+    if config_opts['use_container_host_hostname'] and '%_buildhost' not in config_opts['macros']:
+        config_opts['macros']['%_buildhost'] = socket.getfqdn()
     return config_opts
 
 
