@@ -25,21 +25,22 @@
 # adding each to a local repo
 # so they are available as build deps to next pkg being built
 from __future__ import print_function
-try:
-    from six.moves.urllib_parse import urlsplit
-except ImportError:
-    from urlparse import urlsplit
+
 import cgi
+# pylint: disable=deprecated-module
 import optparse
 import os
 import re
-import requests
 import shutil
 import subprocess
 import sys
 import tempfile
 import time
 
+import requests
+# pylint: disable=import-error
+from six.moves.urllib_parse import urlsplit
+
 import mockbuild.util
 
 # all of the variables below are substituted by the build system
@@ -104,7 +105,7 @@ def parse_args(args):
         sys.exit(1)
 
     if len(sys.argv) < 3:
-        print("You must specifiy at least 1 package to build")
+        print("You must specify at least 1 package to build")
         sys.exit(1)
 
     return opts, args
@@ -137,6 +138,7 @@ def add_local_repo(infile, destfile, baseurl, repoid=None):
     try:
         with open(infile) as f:
             code = compile(f.read(), infile, 'exec')
+        # pylint: disable=exec-used
         exec(code)
         if not repoid:
             repoid = generate_repo_id(baseurl)
@@ -153,10 +155,9 @@ cost=1
 """ % (repoid, baseurl, baseurl)
 
         config_opts['yum.conf'] += localyumrepo
-        br_dest = open(destfile, 'w')
-        for k, v in list(config_opts.items()):
-            br_dest.write("config_opts[%r] = %r\n" % (k, v))
-        br_dest.close()
+        with open(destfile, 'w') as br_dest:
+            for k, v in list(config_opts.items()):
+                br_dest.write("config_opts[%r] = %r\n" % (k, v))
         return True, ''
     except (IOError, OSError):
         return False, "Could not write mock config to %s" % destfile
@@ -213,13 +214,15 @@ def do_build(opts, cfg, pkg):
         mockcmd, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
     out, err = cmd.communicate()
     if cmd.returncode == 0:
-        open(success_file, 'w').write('done\n')
+        with open(success_file, 'w') as f:
+            f.write('done\n')
         ret = 1
     else:
         if (isinstance(err, bytes)):
             err = err.decode("utf-8")
         sys.stderr.write(err)
-        open(fail_file, 'w').write('undone\n')
+        with open(fail_file, 'w') as f:
+            f.write('undone\n')
         ret = 0
 
     return ret, cmd, out, err
@@ -229,7 +232,8 @@ def log(lf, msg):
     if lf:
         now = time.time()
         try:
-            open(lf, 'a').write(str(now) + ':' + msg + '\n')
+            with open(lf, 'a') as f:
+                f.write(str(now) + ':' + msg + '\n')
         except (IOError, OSError) as e:
             print('Could not write to logfile %s - %s' % (lf, str(e)))
     print(msg)
@@ -307,7 +311,7 @@ def main(args):
         shutil.copyfile(pth, opts.config_path + '/' + fn)
 
     # createrepo on it
-    out, err = createrepo(opts.local_repo_dir)
+    err = createrepo(opts.local_repo_dir)[1]
     if err.strip():
         log(opts.logfile, "Error making local repo: %s" % opts.local_repo_dir)
         log(opts.logfile, "Err: %s" % err)
@@ -334,6 +338,7 @@ def main(args):
                 try:
                     log(opts.logfile, 'Fetching %s' % url)
                     r = requests.get(url)
+                    # pylint: disable=no-member
                     if r.status_code == requests.codes.ok:
                         fn = urlsplit(r.url).path.rsplit('/', 1)[1]
                         if 'content-disposition' in r.headers:
@@ -341,10 +346,9 @@ def main(args):
                             if 'filename' in params and params['filename']:
                                 fn = params['filename']
                         pkg = download_dir + '/' + fn
-                        fd = open(pkg, 'wb')
-                        for chunk in r.iter_content(4096):
-                            fd.write(chunk)
-                        fd.close()
+                        with open(pkg, 'wb') as fd:
+                            for chunk in r.iter_content(4096):
+                                fd.write(chunk)
                 except Exception as e:
                     log(opts.logfile, 'Error Downloading %s: %s' % (url, str(e)))
                     failed.append(url)
@@ -352,7 +356,7 @@ def main(args):
                 else:
                     downloaded_pkgs[pkg] = url
             log(opts.logfile, "Start build: %s" % pkg)
-            ret, cmd, out, err = do_build(opts, config_opts['chroot_name'], pkg)
+            ret = do_build(opts, config_opts['chroot_name'], pkg)[0]
             log(opts.logfile, "End build: %s" % pkg)
             if ret == 0:
                 failed.append(pkg)
@@ -365,7 +369,7 @@ def main(args):
                 log(opts.logfile, "Success building %s" % os.path.basename(pkg))
                 built_pkgs.append(pkg)
                 # createrepo with the new pkgs
-                out, err = createrepo(opts.local_repo_dir)
+                err = createrepo(opts.local_repo_dir)[1]
                 if err.strip():
                     log(opts.logfile, "Error making local repo: %s" % opts.local_repo_dir)
                     log(opts.logfile, "Err: %s" % err)
